@@ -110,6 +110,7 @@ def cookiecutter(
         }
         context_for_prompting = {}
         context_for_prompting['cookiecutter'] = items_for_prompting
+        context = context_from_replayfile
         logger.debug('prompting context: %s', context_for_prompting)
     else:
         context = generate_context(
@@ -137,7 +138,7 @@ def cookiecutter(
                 r'\((.*?)\)', context["cookiecutter"]["template"]
             ).group(1)
             return cookiecutter(
-                template=os.path.join(template, nested_template),
+                template=os.path.join(repo_dir, nested_template),
                 checkout=checkout,
                 no_input=no_input,
                 extra_context=extra_context,
@@ -153,16 +154,20 @@ def cookiecutter(
                 keep_project_on_failure=keep_project_on_failure,
             )
 
-    logger.debug('contex is %s', context)
+    logger.debug('context is %s', context)
 
     # include template dir or url in the context dict
     context['cookiecutter']['_template'] = template
 
     # include output+dir in the context dict
     context['cookiecutter']['_output_dir'] = os.path.abspath(output_dir)
+
     # include repo dir or url in the context dict
     context['cookiecutter']['_repo_dir'] = repo_dir
 
+    # include checkout details in the context dict
+    context['cookiecutter']['_checkout'] = checkout
+
     dump(config_dict['replay_dir'], template_name, context)
 
     # Create project from local context and project template.
