@@ -1,7 +1,4 @@
-# -*- coding: utf-8 -*-
-
 """Collection of tests around log handling."""
-
 import logging
 
 import pytest
@@ -38,13 +35,13 @@ def info_messages():
 def debug_messages():
     """Fixture. List of test debug messages."""
     return [
-        'INFO cookiecutter: ' 'Welcome to Cookiecutter',
-        'DEBUG cookiecutter: ' 'Generating project from pytest-plugin',
-        'INFO cookiecutter.foo: ' 'Loading user config from home dir',
-        "DEBUG cookiecutter.foo.bar: " "I don't know.",
-        'DEBUG cookiecutter.foo.bar: ' 'I wanted to save the world.',
-        'ERROR cookiecutter.foo: ' 'Aw, snap! Something went wrong',
-        'DEBUG cookiecutter: ' 'Successfully generated project',
+        "INFO cookiecutter: Welcome to Cookiecutter",
+        "DEBUG cookiecutter: Generating project from pytest-plugin",
+        "INFO cookiecutter.foo: Loading user config from home dir",
+        "DEBUG cookiecutter.foo.bar: I don't know.",
+        "DEBUG cookiecutter.foo.bar: I wanted to save the world.",
+        "ERROR cookiecutter.foo: Aw, snap! Something went wrong",
+        "DEBUG cookiecutter: Successfully generated project",
     ]
 
 
@@ -61,9 +58,9 @@ def debug_logger():
 
 
 @pytest.fixture
-def debug_file(tmpdir):
+def debug_file(tmp_path):
     """Fixture. Generate debug file location for tests."""
-    return tmpdir / 'pytest-plugin.log'
+    return tmp_path.joinpath('pytest-plugin.log')
 
 
 @pytest.fixture
@@ -120,4 +117,5 @@ def test_debug_file_logging(caplog, info_logger_with_file, debug_file, debug_mes
     assert debug_file.exists()
 
     # Last line in the log file is an empty line
-    assert debug_file.readlines(cr=False) == debug_messages + ['']
+    with debug_file.open() as f:
+        assert f.read().split('\n') == debug_messages + ['']
