@@ -1,17 +1,17 @@
 """Tests around prompting for and handling of choice variables."""
-import click
 import pytest
 
 from cookiecutter.prompt import read_user_choice
 
 OPTIONS = ['hello', 'world', 'foo', 'bar']
+OPTIONS_INDEX = ['1', '2', '3', '4']
 
-EXPECTED_PROMPT = """Select varname:
-1 - hello
-2 - world
-3 - foo
-4 - bar
-Choose from 1, 2, 3, 4"""
+EXPECTED_PROMPT = """Select varname
+    [bold magenta]1[/] - [bold]hello[/]
+    [bold magenta]2[/] - [bold]world[/]
+    [bold magenta]3[/] - [bold]foo[/]
+    [bold magenta]4[/] - [bold]bar[/]
+    Choose from"""
 
 
 @pytest.mark.parametrize('user_choice, expected_value', enumerate(OPTIONS, 1))
@@ -20,17 +20,12 @@ def test_click_invocation(mocker, user_choice, expected_value):
 
     Test for choice type invocation.
     """
-    choice = mocker.patch('click.Choice')
-    choice.return_value = click.Choice(OPTIONS)
-
-    prompt = mocker.patch('click.prompt')
+    prompt = mocker.patch('rich.prompt.Prompt.ask')
     prompt.return_value = f'{user_choice}'
 
     assert read_user_choice('varname', OPTIONS) == expected_value
 
-    prompt.assert_called_once_with(
-        EXPECTED_PROMPT, type=click.Choice(OPTIONS), default='1', show_choices=False
-    )
+    prompt.assert_called_once_with(EXPECTED_PROMPT, choices=OPTIONS_INDEX, default='1')
 
 
 def test_raise_if_options_is_not_a_non_empty_list():
